@@ -115,9 +115,10 @@ def finish(request):
         logger.debug('Setting up the OpenID response object')
         response = con.complete(request_args, return_to)
 
-        profile = process_profile_data(response, settings.XAUTH_PROFILE_FIELDS)
 
         if response.status == consumer.SUCCESS:
+            profile = process_profile_data(response, settings.XAUTH_PROFILE_FIELDS)
+
             identity = response.identity_url
             request.session['xauth_response'] = {
                 'service': 'openid',
@@ -128,7 +129,12 @@ def finish(request):
             }
             return redirect('xauth_complete')
         else:
-            messages.error(request, _('OpenID authentication failure: %s' % response.message))
+            if response.status == consumer.CANCEL:
+                messages.error(request, _('Authentication cancelled'))
+            elif response.status == consumer.FAILURE:
+                messages.error(request, _('OpenID authentication failure: %s' % response.message))
+            else:
+                messages.error(request, _('Unknown OpenID response type: %s' % response.status))
             return redirect('xauth_login')
     else:
         messages.error(request, u'Invalid openid data')
